@@ -1,4 +1,4 @@
-from py42._internal.compat import str
+from py42._compat import str
 from py42.sdk.queries import BaseQuery
 from py42.sdk.queries.query_filter import create_filter_group
 from py42.sdk.queries.query_filter import create_query_filter
@@ -8,10 +8,11 @@ from py42.sdk.queries.query_filter import QueryFilterStringField
 class FileEventQuery(BaseQuery):
     """Helper class for building Code42 Forensic Search queries.
 
-    A FileEventQuery instance's ``all()`` and ``any()`` take one or more :class:`FilterGroup`
-    objects to construct a query that can be passed to the :meth:`FileEventClient.search()` method.
-    ``all()`` returns results that match all of the provided filter criteria, ``any()`` will return
-    results that match any of the filters.
+    A FileEventQuery instance's ``all()`` and ``any()`` take one or more
+    :class:`~py42.sdk.queries.query_filter.FilterGroup` objects to construct a query that
+    can be passed to the :meth:`FileEventService.search()` method. ``all()`` returns results
+    that match all of the provided filter criteria, ``any()`` will return results that
+    match any of the filters.
 
     For convenience, the :class:`FileEventQuery` constructor does the same as ``all()``.
 
@@ -19,7 +20,6 @@ class FileEventQuery(BaseQuery):
 
         email_filter = EmailSender.is_in(["test.user@example.com", "test.sender@example.com"])
         exposure_filter = ExposureType.exists()
-
         query = FileEventQuery.all(email_filter, exposure_filter)
 
     """
@@ -54,25 +54,69 @@ class FileEventQuery(BaseQuery):
             u"srtKey": self.sort_key,
         }
         for key in output_dict:
-            yield (key, output_dict[key])
+            yield key, output_dict[key]
 
 
 def create_exists_filter_group(term):
+    """Creates a :class:`~py42.sdk.queries.query_filter.FilterGroup` to find events where
+    filter data exists. Useful for creating ``EXISTS`` filters that are not yet supported
+    in py42 or programmatically crafting filter groups.
+
+    Args:
+        term (str): The term of the filter.
+
+    Returns:
+        :class:`~py42.sdk.queries.query_filter.FilterGroup`
+    """
     filter_list = [create_query_filter(term, u"EXISTS")]
     return create_filter_group(filter_list, u"AND")
 
 
 def create_not_exists_filter_group(term):
+    """Creates a :class:`~py42.sdk.queries.query_filter.FilterGroup` to find events where
+    filter data does not exist. Useful for creating ``DOES_NOT_EXIST`` filters that are
+    not yet supported in py42 or programmatically crafting filter groups.
+
+    Args:
+        term (str): The term of the filter.
+
+    Returns:
+        :class:`~py42.sdk.queries.query_filter.FilterGroup`
+    """
     filter_list = [create_query_filter(term, u"DOES_NOT_EXIST")]
     return create_filter_group(filter_list, u"AND")
 
 
 def create_greater_than_filter_group(term, value):
+    """Creates a :class:`~py42.sdk.queries.query_filter.FilterGroup` for matching file
+    events where the value with key ``term`` is greater than the given value. Useful for
+    creating ``GREATER_THAN`` filters that are not yet supported in py42 or programmatically
+    crafting filter groups.
+
+    Args:
+        term (str): The term of the filter.
+        value (str or int): The value used to filter file events.
+
+    Returns:
+        :class:`~py42.sdk.queries.query_filter.FilterGroup`
+    """
     filter_list = [create_query_filter(term, u"GREATER_THAN", value)]
     return create_filter_group(filter_list, u"AND")
 
 
 def create_less_than_filter_group(term, value):
+    """Creates a :class:`~py42.sdk.queries.query_filter.FilterGroup` for matching file
+    events where the value with key ``term`` is less than the given value. Useful for creating
+    ``LESS_THAN`` filters that are not yet supported in py42 or programmatically crafting
+    filter groups.
+
+    Args:
+        term (str): The term of the filter.
+        value (str or int): The value used to filter file events.
+
+    Returns:
+        :class:`~py42.sdk.queries.query_filter.FilterGroup`
+    """
     filter_list = [create_query_filter(term, u"LESS_THAN", value)]
     return create_filter_group(filter_list, u"AND")
 
@@ -82,12 +126,22 @@ class FileEventFilterStringField(QueryFilterStringField):
 
     @classmethod
     def exists(cls):
-        """Returns a :class:`FilterGroup` to find events where filter data exists."""
+        """Returns a :class:`~py42.sdk.queries.query_filter.FilterGroup` to find events
+        where filter data exists.
+
+        Returns:
+            :class:`~py42.sdk.queries.query_filter.FilterGroup`
+        """
         return create_exists_filter_group(cls._term)
 
     @classmethod
     def not_exists(cls):
-        """Returns a :class:`FilterGroup` to find events where filter data does not exist."""
+        """Returns a :class:`~py42.sdk.queries.query_filter.FilterGroup` to find events
+        where filter data does not exist.
+
+        Returns:
+            :class:`~py42.sdk.queries.query_filter.FilterGroup`
+        """
         return create_not_exists_filter_group(cls._term)
 
 
@@ -98,16 +152,28 @@ class FileEventFilterComparableField(object):
 
     @classmethod
     def greater_than(cls, value):
-        """Returns a :class:`FilterGroup` to find events where filter data is greater than the
-        provided value.
+        """Returns a :class:`~py42.sdk.queries.query_filter.FilterGroup` to find events
+        where filter data is greater than the provided value.
+
+        Args:
+            value (str or int or float): The value used to filter file events.
+
+        Returns:
+            :class:`~py42.sdk.queries.query_filter.FilterGroup`
         """
         value = int(value)
         return create_greater_than_filter_group(cls._term, value)
 
     @classmethod
     def less_than(cls, value):
-        """Returns a :class:`FilterGroup` to find events where filter data is less than than the
-        provided value.
+        """Returns a :class:`~py42.sdk.queries.query_filter.FilterGroup` to find events
+        where filter data is less than than the provided value.
+
+        Args:
+            value (str or int or float): The value used to filter file events.
+
+        Returns:
+            :class:`~py42.sdk.queries.query_filter.FilterGroup`
         """
         value = int(value)
         return create_less_than_filter_group(cls._term, value)
