@@ -1,4 +1,5 @@
 from py42.sdk.queries.fileevents.file_event_query import FileEventFilterStringField
+from py42.sdk.queries.query_filter import filter_attributes
 
 
 class ExposureType(FileEventFilterStringField):
@@ -23,6 +24,10 @@ class ExposureType(FileEventFilterStringField):
     IS_PUBLIC = u"IsPublic"
     OUTSIDE_TRUSTED_DOMAINS = u"OutsideTrustedDomains"
 
+    @staticmethod
+    def choices():
+        return filter_attributes(ExposureType)
+
 
 class ProcessName(FileEventFilterStringField):
     """Class that filters events based on the process name involved in the exposure (applies to
@@ -114,6 +119,10 @@ class SyncDestination(FileEventFilterStringField):
     DROPBOX = u"Dropbox"
     ONEDRIVE = u"OneDrive"
 
+    @staticmethod
+    def choices():
+        return filter_attributes(SyncDestination)
+
 
 class TabURL(FileEventFilterStringField):
     """Class that filters events based on the URL of the active browser tab at the time the file
